@@ -303,7 +303,7 @@ int main(int argc, char **argv){
       case XK_Delete: case XK_BackSpace:
         if (rlen>0) rlen--;
         break;
-      case XK_Linefeed: case XK_Return:
+      case XK_Linefeed: case XK_Return: case XK_KP_Enter:
         if (rlen==0) break;
         rbuf[rlen]=0;
         if (passwordok(rbuf)) goto loop_x;
